@@ -43,7 +43,7 @@ import sys
 import uuid
 import zipfile
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 __EXITOKAY__ = 0
 FILE_DIR = ".pyppyn"
@@ -221,14 +221,15 @@ class ConfigRep:
     def _wheel_top_level(self):
         # top level
         logger.info("Looking at wheel top level")
-        self.config["top_level"] = open("top_level.txt", "r").read().strip()
+        with open("top_level.txt", "r", encoding="utf8") as top:
+            self.config["top_level"] = top.read().strip()
 
     def _wheel_console_scripts(self):
         # console scripts
         logger.info("Reading names of console scripts")
         self.config["console_scripts"] = []
         console_scripts = False
-        with open("entry_points.txt", "r") as ep_file:
+        with open("entry_points.txt", "r", encoding="utf8") as ep_file:
             for line in ep_file:
                 if line.startswith("[console_scripts]"):
                     console_scripts = True
@@ -241,7 +242,7 @@ class ConfigRep:
         # metadata
         logger.info("Reading wheel metadata")
         bulk = ""
-        with open("METADATA", "r") as metadata_fh:
+        with open("METADATA", "r", encoding="utf8") as metadata_fh:
             bulk = metadata_fh.read()
 
         parts = bulk.split("\n\n")
