@@ -1,7 +1,12 @@
 # -*- coding: utf-8 -*-
 """pyppyn setup script."""
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals, with_statement)
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+    unicode_literals,
+    with_statement,
+)
 
 from setuptools import setup
 
@@ -10,5 +15,5 @@ if __name__ == "__main__":
     setup(
         name="minipippy",
         description="Not a real package, just for testing Pyppyn.",
-        package_dir={'': 'src'}
+        package_dir={"": "src"},
     )
